@@ -44,8 +44,6 @@ class Q_DECL_HIDDEN RichTextComposer::RichTextComposerPrivate
 public:
     RichTextComposerPrivate(RichTextComposer *qq)
         : q(qq)
-        , mode(RichTextComposer::Plain)
-        , forcePlainTextMarkup(false)
     {
         composerControler = new RichTextComposerControler(q, q);
         richTextComposerActions = new RichTextComposerActions(composerControler, q);
@@ -60,7 +58,7 @@ public:
     RichTextComposerActions *richTextComposerActions = nullptr;
     KPIMTextEdit::RichTextExternalComposer *externalComposer = nullptr;
     RichTextComposer *q = nullptr;
-    RichTextComposer::Mode mode;
+    RichTextComposer::Mode mode = RichTextComposer::Plain;
     bool forcePlainTextMarkup = false;
 };
 
@@ -98,7 +96,7 @@ QList<QAction *> RichTextComposer::richTextActionList() const
 
 void RichTextComposer::setEnableActions(bool state)
 {
-    Q_FOREACH (QAction *act, richTextActionList()) {
+    for (QAction *act : richTextActionList()) {
         act->setEnabled(state);
     }
 }
