@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -40,7 +40,9 @@ public:
 
         imageWidget = new InsertImageWidget(q);
         vbox->addWidget(imageWidget);
-        q->connect(imageWidget, &InsertImageWidget::enableButtonOk, q, [this](bool b) { _k_slotEnabledButtonChanged(b); });
+        q->connect(imageWidget, &InsertImageWidget::enableButtonOk, q, [this](bool b) {
+                _k_slotEnabledButtonChanged(b);
+            });
         QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         okButton = buttonBox->button(QDialogButtonBox::Ok);
         okButton->setText(i18n("Insert"));
