@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,7 +19,7 @@
 
 #include "texteditfindbarbase.h"
 #include "texteditor/commonwidget/textfindreplacewidget.h"
-
+#include "kpimtextedit_debug.h"
 #include <QIcon>
 #include <KLocalizedString>
 #include <kmessagebox.h>
@@ -83,7 +83,7 @@ void TextEditFindBarBase::showFind()
     if (documentIsEmpty()) {
         return;
     }
-    mReplaceWidget->slotSearchStringEmpty(mFindWidget->search()->text().isEmpty());
+    mReplaceWidget->slotSearchStringEmpty(mFindWidget->searchText().isEmpty());
     show();
     if (mReplaceWidget->isVisible()) {
         mReplaceWidget->hide();
@@ -104,7 +104,7 @@ void TextEditFindBarBase::showReplace()
     if (documentIsEmpty()) {
         return;
     }
-    mReplaceWidget->slotSearchStringEmpty(mFindWidget->search()->text().isEmpty());
+    mReplaceWidget->slotSearchStringEmpty(mFindWidget->searchText().isEmpty());
     show();
     if (!mReplaceWidget->isVisible()) {
         mReplaceWidget->show();
@@ -114,19 +114,19 @@ void TextEditFindBarBase::showReplace()
 
 void TextEditFindBarBase::setText(const QString &text)
 {
-    mFindWidget->search()->setText(text);
+    mFindWidget->searchLineEdit()->setText(text);
 }
 
 QString TextEditFindBarBase::text() const
 {
-    return mFindWidget->search()->text();
+    return mFindWidget->searchText();
 }
 
 void TextEditFindBarBase::focusAndSetCursor()
 {
     setFocus();
-    mFindWidget->search()->selectAll();
-    mFindWidget->search()->setFocus();
+    mFindWidget->searchLineEdit()->selectAll();
+    mFindWidget->searchLineEdit()->setFocus();
 }
 
 void TextEditFindBarBase::slotClearSearch()
@@ -138,7 +138,9 @@ void TextEditFindBarBase::autoSearch(const QString &str)
 {
     const bool isNotEmpty = (!str.isEmpty());
     if (isNotEmpty) {
-        QTimer::singleShot(0, this, [this]() { slotSearchText(); });
+        QTimer::singleShot(0, this, [this]() {
+            slotSearchText();
+        });
     } else {
         clearSelections();
     }
@@ -159,7 +161,8 @@ void TextEditFindBarBase::messageInfo(bool backward, bool isAutoSearch, bool fou
 
 bool TextEditFindBarBase::searchText(bool backward, bool isAutoSearch)
 {
-    mLastSearchStr = mFindWidget->search()->text();
+    mLastSearchStr = mFindWidget->searchText();
+    mLastSearchRegExp = mFindWidget->searchRegExp();
     QTextDocument::FindFlags searchOptions = mFindWidget->searchOptions();
     if (backward) {
         searchOptions |= QTextDocument::FindBackward;
@@ -167,11 +170,18 @@ bool TextEditFindBarBase::searchText(bool backward, bool isAutoSearch)
 
     if (isAutoSearch) {
         autoSearchMoveCursor();
-    } else if (!mLastSearchStr.contains(mFindWidget->search()->text(), Qt::CaseSensitive)) {
+    } else if (mFindWidget->isRegularExpression()) {
+        //TODO
+    } else if (!mLastSearchStr.contains(mFindWidget->searchText(), Qt::CaseSensitive)) {
         clearSelections();
     }
 
-    const bool found = searchInDocument(mLastSearchStr, searchOptions);
+    bool found = false;
+    if (mFindWidget->isRegularExpression()) {
+        found = searchInDocument(mLastSearchRegExp, searchOptions);
+    } else {
+        found = searchInDocument(mLastSearchStr, searchOptions);
+    }
     mFindWidget->setFoundMatch(found);
     messageInfo(backward, isAutoSearch, found);
     return found;
@@ -190,8 +200,13 @@ void TextEditFindBarBase::findPrev()
 void TextEditFindBarBase::slotUpdateSearchOptions()
 {
     const QTextDocument::FindFlags searchOptions = mFindWidget->searchOptions();
-    mLastSearchStr = mFindWidget->search()->text();
-    searchInDocument(mLastSearchStr, searchOptions);
+    mLastSearchStr = mFindWidget->searchText();
+    mLastSearchRegExp = mFindWidget->searchRegExp();
+    if (mFindWidget->isRegularExpression()) {
+        searchInDocument(mLastSearchRegExp, searchOptions);
+    } else {
+        searchInDocument(mLastSearchStr, searchOptions);
+    }
 }
 
 void TextEditFindBarBase::clearSelections()
@@ -202,8 +217,8 @@ void TextEditFindBarBase::clearSelections()
 void TextEditFindBarBase::closeBar()
 {
     // Make sure that all old searches are cleared
-    mFindWidget->search()->setText(QString());
-    mReplaceWidget->replace()->setText(QString());
+    mFindWidget->searchLineEdit()->setText(QString());
+    mReplaceWidget->replaceLineEdit()->setText(QString());
     clearSelections();
     mReplaceWidget->hide();
     updateGeometry();
@@ -236,7 +251,7 @@ bool TextEditFindBarBase::event(QEvent *e)
             if (shortCutOverride) {
                 return true;
             }
-            if (mFindWidget->search()->text().isEmpty()) {
+            if (mFindWidget->searchText().isEmpty()) {
                 return true;
             }
 
