@@ -36,7 +36,6 @@
 #include <Sonnet/Highlighter>
 #include <sonnet/spellcheckdecorator.h>
 #include <sonnet/speller.h>
-#include <sonnet_version.h>
 #include <texttospeech/texttospeech.h>
 #include <SonnetCore/sonnet/backgroundchecker.h>
 #include <KIO/KUriFilterSearchProviderActions>
@@ -60,13 +59,7 @@ public:
     RichTextEditorPrivate(RichTextEditor *qq)
         : q(qq)
         , textIndicator(new KPIMTextEdit::TextMessageIndicator(q))
-        , richTextDecorator(nullptr)
-        , speller(nullptr)
         , webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q))
-        , mInitialFontSize(0)
-        , customPalette(false)
-        , activateLanguageMenu(true)
-        , showAutoCorrectionButton(false)
     {
         KConfig sonnetKConfig(QStringLiteral("sonnetrc"));
         KConfigGroup group(&sonnetKConfig, "Spelling");
@@ -95,10 +88,10 @@ public:
     KIO::KUriFilterSearchProviderActions *webshortcutMenuManager = nullptr;
     RichTextEditor::SupportFeatures supportFeatures;
     int mInitialFontSize;
-    bool customPalette;
-    bool checkSpellingEnabled;
-    bool activateLanguageMenu;
-    bool showAutoCorrectionButton;
+    bool customPalette = false;
+    bool checkSpellingEnabled = false;
+    bool activateLanguageMenu = true;
+    bool showAutoCorrectionButton = false;
 };
 
 RichTextEditor::RichTextEditor(QWidget *parent)
@@ -116,6 +109,12 @@ RichTextEditor::~RichTextEditor()
     delete d;
 }
 
+void RichTextEditor::setDefaultFontSize(int val)
+{
+    d->mInitialFontSize = val;
+    slotZoomReset();
+}
+
 void RichTextEditor::slotDisplayMessageIndicator(const QString &message)
 {
     d->textIndicator->display(message);
@@ -651,9 +650,7 @@ void RichTextEditor::setSpellCheckingLanguage(const QString &_language)
 {
     if (highlighter()) {
         highlighter()->setCurrentLanguage(_language);
-#if SONNET_VERSION < QT_VERSION_CHECK(5, 49, 0)
         highlighter()->rehighlight();
-#endif
     }
 
     if (_language != d->spellCheckingLanguage) {
@@ -919,6 +916,16 @@ void RichTextEditor::keyPressEvent(QKeyEvent *event)
     }
 }
 
+int RichTextEditor::zoomFactor() const
+{
+    int pourcentage = 100;
+    QFont f = font();
+    if (d->mInitialFontSize != f.pointSize()) {
+        pourcentage = (f.pointSize() * 100) / d->mInitialFontSize;
+    }
+    return pourcentage;
+}
+
 void RichTextEditor::slotZoomReset()
 {
     QFont f = font();
@@ -940,7 +947,7 @@ void RichTextEditor::moveLineUpDown(bool moveUp)
         move.setPosition(cursor.selectionStart());
         move.movePosition(QTextCursor::StartOfBlock);
         move.setPosition(cursor.selectionEnd(), QTextCursor::KeepAnchor);
-        move.movePosition(move.atBlockStart() ? QTextCursor::Left: QTextCursor::EndOfBlock,
+        move.movePosition(move.atBlockStart() ? QTextCursor::Left : QTextCursor::EndOfBlock,
                           QTextCursor::KeepAnchor);
     } else {
         move.movePosition(QTextCursor::StartOfBlock);
